@@ -1,4 +1,4 @@
-# $Id$
+# $Id: /mirror/coderepos/lang/perl/Google-Chart/trunk/lib/Google/Chart/Fill/Solid.pm 67466 2008-07-30T01:53:50.528367Z daisuke  $
 
 package Google::Chart::Fill::Solid;
 use Moose;
@@ -22,7 +22,6 @@ has 'target' => (
 __PACKAGE__->meta->make_immutable;
 
 no Moose;
-no Moose::Util::TypeConstraints;
 
 sub parameter_value {
     my $self = shift;
@@ -37,23 +36,8 @@ __END__
 
 Google::Chart::Fill::Solid - Apply Solid Fill
 
-=head1 SYNOPSIS
+=head1 METHODS
 
-  use Google::Chart;
-  Google::Chart->new(
-    fill => {
-      args => {
-        color => "ffccff",
-        target => "bg",
-      }
-    }
-  );
-
-  Google::Chart->new(
-    fill => Google::Chart::Fill::Solid->new(
-      color => "ffcff",
-      target => "bg"
-    )
-  );
+=head2 parameter_value
 
 =cut
